@@ -8,11 +8,11 @@ from djangoldp_skill.models import Skill
 
 class JobOffer(Model):
     author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='jobOffers', on_delete=models.CASCADE)
-    title = models.CharField(max_length=255)
-    description = models.TextField()
-    skills = models.ManyToManyField(Skill)
+    title = models.CharField(max_length=255, blank=True, null=True)
+    description = models.TextField(blank=True, null=True)
+    skills = models.ManyToManyField(Skill, blank=True)
     creationDate = models.DateTimeField(auto_now_add=True)
-    closingDate = models.DateField()
+    closingDate = models.DateField(null=True)
     conversation = models.ManyToManyField(Conversation, blank=True)
 
     class Meta:
